@@ -1,11 +1,22 @@
+import inspect
+import os
+
 import jug.jug
 import jug.task
 from jug.task import Task
 from jug.tests.utils import simple_execute
 from jug.backends.dict_store import dict_store
+from .task_reset import task_reset
+
 import random
 jug.jug.silent = True
 
+
+_jugdir = os.path.abspath(inspect.getfile(inspect.currentframe()))
+_jugdir = os.path.join(os.path.dirname(_jugdir), 'jugfiles')
+
+
+@task_reset
 def test_jug_execute_simple():
     N = 1024
     random.seed(232)
@@ -19,6 +30,7 @@ def test_jug_execute_simple():
     assert False not in A
     assert max(store.counts.values()) < 4
 
+@task_reset
 def test_jug_execute_deps():
     N = 256
     random.seed(234)
@@ -34,9 +46,8 @@ def test_jug_execute_deps():
     jug.task.Task.store = store
     simple_execute()
     assert False not in A
-    assert max(store.counts.values()) < 4
+    assert max(store.counts.values()) < 5
 
-from .task_reset import task_reset
 def test_aggressive_unload():
     from jug.jug import execution_loop
     from jug.task import alltasks
@@ -47,9 +58,9 @@ def test_aggressive_unload():
     def run_jugfile(jugfile):
         store, space = jug.jug.init(jugfile, 'dict_store')
         execution_loop(alltasks, options)
-    yield run_jugfile, 'jug/tests/jugfiles/tasklet_simple.py'
-    yield run_jugfile, 'jug/tests/jugfiles/tasklets.py'
-    yield run_jugfile, 'jug/tests/jugfiles/barrier_mapreduce.py'
-    yield run_jugfile, 'jug/tests/jugfiles/compound_nonsimple.py'
-    yield run_jugfile, 'jug/tests/jugfiles/slice_task.py'
+    yield run_jugfile, os.path.join(_jugdir, 'tasklet_simple.py')
+    yield run_jugfile, os.path.join(_jugdir, 'tasklets.py')
+    yield run_jugfile, os.path.join(_jugdir, 'barrier_mapreduce.py')
+    yield run_jugfile, os.path.join(_jugdir, 'compound_nonsimple.py')
+    yield run_jugfile, os.path.join(_jugdir, 'slice_task.py')
 
